/****************************************************************************
 *   Copyright (C) 2004 by Arboretum Systems, Inc.                          *
 *   Technical administrator: Alain Mazy, hav@mazy.be                       *
 *   Lead program designer: Georges Jaroslaw, gjaro@arboretum.com           *
 *                                                                          *
 *   HyperEngine-AV is a video, audio and text editor that can be used to   *
 *   record, import, edit, process and arrange together video, sound and    *
 *   text. These are all achieved in the program's free-form document       *
 *   window, with no limitations to the number of tracks.                   *
 *   The purpose of this program is to provide to users at all levels of    *
 *   expertise a readily accessible tool enabling them to create movies,    *
 *   slide shows or presentations.                                          *
 *                                                                          *
 *   HyperEngine-AV itself is free software. However, plug-ins that can be  *
 *   used as add-ons to HyperEngine-AV may or may not be free software, at  *
 *   the discretion of each plug-in developer and as specified by these     *
 *   plug-ins' respective licenses.                                         *
 *   You can redistribute HyperEngine-AV itself and/or modify it under the  *
 *   terms of the GNU General Public License as published by the Free       *
 *   Software Foundation; either version 2 of the License, or (at your      *
 *   option) any later version.                                             *
 *                                                                          *
 *   HyperEngine-AV is distributed in the hope that it will be useful, but  *
 *   WITHOUT ANY WARRANTY; without even the implied warranty of             *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
 *   GNU General Public License for all applicable details.                 *
 *                                                                          *
 *   You should have received a copy of the GNU General Public License      *
 *   along with this program; if not, write to:                             *
 *   Free Software Foundation, Inc.,                                        *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.              *
 ****************************************************************************/

#define VArmeMediaFileHandler_h

#ifndef ArmeBasicTypes_h
#include "ArmeBasicTypes.h"
#endif //ArmeBasicTypes_h

#ifndef VArmeMediaFileHandler_h
#include "VArmeMediaFileHandler.h"
#endif //VArmeMediaFileHandler_h

class TArmeDoc;
class TArmeWSObj;
class TArmeWSObjPos;
class ZzSplitTask;
class ZzArchPtrArray;
class ArmeDataFileRef;
class ZzString;

/*! 

	@class VArmeMediaFileHandler
	@abstract Class that creates clips from files
	@discussion This class is the base class for the media handlers. These
	object create clips from files. For example, a QuickTime media
	handler will create a video clip and an audio clip for a classic
	QuickTime movie (it can also create text tracks if there are some) 
	
	The TArmeMediaEngine class holds a list of all the installed media
	handlers.

*/
 
class MIProgressBarDlgManager;

class VArmeMediaFileHandler
{
public :
	virtual ~VArmeMediaFileHandler() {};
	/*! 
		@function GetSupportedExtensionsCount This function reports the number of different file
		extensions that the handler MAY support. This function is useful to register oneself by
		the drag & drop manager (???)
	*/
	virtual int32		GetSupportedExtensionsCount() = 0;
	
	/*!
		@function GetSupportedExtension Returns the i-th supported file extension
	*/
	virtual char*		GetSupportedExtension(int32 i) = 0;

        /*!
            @function GetSupportedTypesCount This function reports the number of different file
         types that the handler MAY support. This function is useful to register oneself by
         the drag & drop manager or the import menu item.
         */
        virtual int32		GetSupportedTypesCount() = 0;

        /*!
            @function GetSupportedType Returns the i-th supported file type
         */
        virtual char*		GetSupportedType(int32 i) = 0;
        
	
	/*!
		@function CanHandleFile Returns true if the handler can handle the file. Please note this is not
		an absolute guarantee the file will be imported without problems... But problems occuring later 
		in the importing process are errors and should be treated as such (message box).
	*/
	virtual bool		CanHandleFileByLookingAtExtension( const ZzString* path );

	virtual bool		CanHandleFileByLookingAtType( const ZzString* path ) = 0;
	
	/*!
		@function CreateWSObjFromFile This function actually creates the clips from the file
	*/
/*
	virtual TArmeWSObj*	CreateWSObjFromFile( 
							TArmeDoc* 					pDoc, 
						//	const char*					path, 
							const ZzString*				cstrPath,
							const TArmeWSObjPos&		pos,
							MIProgressBarDlgManager*	progressMngr,
							ArmeErr*					err) = 0;
*/

	virtual ArmeErr		CreateWSObjsFromFile( 
							TArmeDoc* 					pDoc,
							ZzArchPtrArray*				theObjects,
						//	const char*					path, 
							const ZzString*				cstrPath,
							ArmeDataFileRef*			fileRef, 
							const TArmeWSObjPos&		pos,
							MIProgressBarDlgManager*	progressMngr) = 0;
						
};	

